/*
 * Copyright 2009 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.local;

import java.util.logging.Level;
import java.util.logging.Logger;

import dk.vajhoej.isam.IsamException;
import dk.vajhoej.isam.IsamResult;
import dk.vajhoej.record.FastStructReader;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.StructReader;

/**
 * Class LocalIsamResult is a result from a find operation in a local ISAM source.
 */
public class LocalIsamResult<T> implements IsamResult<T> {
    private static Logger log = Logger.getLogger(LocalIsamResult.class.getName());
    private Class<T> t;
    private NativeIsam del;
    private byte[] buf;
    private boolean firstfnd;
    private boolean first;
    /**
     * Create instance of LocalIsamResult.
     * @param t type to load
     * @param del delegate to NativeIsam
     * @param buf buffer to receive data
     * @param firstfnd whether first record was found
     */
    public LocalIsamResult(Class<T> t, NativeIsam del, byte[] buf, boolean firstfnd) {
        this.t = t;
        this.del = del;
        this.buf = buf;
        this.firstfnd = firstfnd;
        first = true;
    }
    public boolean read() throws IsamException, RecordException {
        log.fine("Result read");
        if(first) {
            first = false;
            return firstfnd;
        } else {
            return del.findnext(buf) > 0;
        }
    }
    public T current() throws IsamException, RecordException {
        log.fine("Result current");
        log.finest("Length: " + buf.length);
        if(log.isLoggable(Level.FINEST)) {
            log.finest("Bytes:" + LogHelper.byteArrayToString(buf, 16));
        }
		if(LocalIsamSource.useFastStruct) {
			FastStructReader<T> fsr = FastSupport.getReader(t);
			fsr.init(buf);
	        return fsr.read(t);
		} else {
	        StructReader sr = new StructReader(buf);
	        return sr.read(t);
		}
    }
    public void close() throws IsamException {
        log.fine("Result close");
        if(!del.supportFindMixedOther()) {
        	del.close();
        }
    }
}
