/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.map;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.logging.Logger;

import dk.vajhoej.isam.IsamSource;

/**
 * Class PyIsamSubMap is a Jython friendly wrapper around IsamSubMap.
 *
 * @param <K> key type
 * @param <R> record type
 */
public class PyIsamSubMap <K extends Comparable<K>,R> extends IsamSubMap<K,R> {
	private static Logger log = Logger.getLogger(PyIsamSubMap.class.getName());
	// **** construct ****
	protected PyIsamSubMap(Class<R> recordClass, IsamSource src, int keyIndex, K startKey, K stopKey) {
		super(recordClass, src, keyIndex, startKey, stopKey);
		log.fine("Instance for " + recordClass + " instantiated");
	}
	// **** provide compatibility with Python dictionary ****
	/**
	 * Jython friendly alias for keySet().
	 * @return key set
	 */
	public Set<K> keys() {
		Set<K> res = keySet();
		log.finest("keys() returning " + res);
		return res;
	}
	/**
	 * Jython friendly wrapper around entrySet().
	 * @return list of entries
	 */
	public List<List<Object>> items() {
		List<List<Object>> res = new ArrayList<List<Object>>();
		for(Entry<K,R> e : entrySet()) {
			List<Object> ee = new ArrayList<Object>();
			ee.add(e.getKey());
			ee.add(e.getValue());
			res.add(ee);
		}
		log.finest("items() returning " + res);
		return res;
	}
}
