/*
 * Copyright 2009 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.remote;

import dk.vajhoej.isam.IsamException;
import dk.vajhoej.isam.IsamResult;
import dk.vajhoej.record.RecordException;

/**
 * Class RemoteIsamResult is a result from a find operation in a remote ISAM source.
 */
public class RemoteIsamResult<T> implements IsamResult<T> {
    private IsamProtocolClient del;
	/**
	 * Create instance of RemoteIsamResult.
	 * @param del client protocol implementation
	 */
	public RemoteIsamResult(IsamProtocolClient del) {
	    this.del = del;
	}
	public boolean read() throws IsamException, RecordException {
	    return del.resultRead();
	}
	@SuppressWarnings("unchecked")
    public T current() throws IsamException, RecordException {
	    return (T)del.resultCurrent();
	}
	public void close() throws IsamException {
	    del.resultClose();
	}
}
